#include "construction.hh"

MyDetectorConstruction::MyDetectorConstruction()
   : fThickness(10.0 * mm), fRadius(10.0 * mm)   // Default values
{
  fMessenger = new G4GenericMessenger(this, "/target/", "Target material setup");
  fMessenger->DeclarePropertyWithUnit("thickness","mm",fThickness,"Thickness of the target material");
  fMessenger->DeclarePropertyWithUnit("radius","mm",fRadius,"Radius of the target material");
  DefineMaterials();
}
// --------------------------------------------------------------------------------------------------------
MyDetectorConstruction::~MyDetectorConstruction()
{
  delete fMessenger;
}
// --------------------------------------------------------------------------------------------------------
void MyDetectorConstruction::DefineMaterials()
{
   G4NistManager *nist = G4NistManager::Instance();

   // world material
   worldMaterial = nist->FindOrBuildMaterial("G4_AIR");

   // target material
   elCu = new G4Element("copper","Cu",29,63.55*g/mole);
   targetMaterial = new G4Material("CU",8.93*g/cm3,1);
   targetMaterial->AddElement(elCu,1);
}
// --------------------------------------------------------------------------------------------------------
G4VPhysicalVolume *MyDetectorConstruction::Construct()
{
   // Define World
   solidWorld = new G4Box("solidWorld",0.5*m, 0.5*m, 0.5*m);
   logicWorld = new G4LogicalVolume(solidWorld,worldMaterial,"logicWorld");
   physWorld  = new G4PVPlacement(0,G4ThreeVector(0,0,0), logicWorld, "pyhsWorld", 0, false, 0, true);

   // Define geometry of target
   solidRadiator = new G4Tubs("solidRadiator", 0.0*mm, fRadius, fThickness, 0.0*deg, 360*deg);
   logicRadiator = new G4LogicalVolume(solidRadiator,targetMaterial,"logicRadiator");
   physRadiator  = new G4PVPlacement(0,G4ThreeVector(0,0,0.25*m),logicRadiator,"physRadiator", logicWorld, false, 0, true);

   // Define detector
   solidDetector = new G4Box("solidDetector",0.5*m,0.5*m,0.01*m);
   logicDetector = new G4LogicalVolume(solidDetector,worldMaterial,"logicDetector");
   physDetector  = new G4PVPlacement(0,G4ThreeVector(0,0,0.5*m),logicDetector, "physDetector", logicWorld, false, 0, true);

   return physWorld;
}
// --------------------------------------------------------------------------------------------------------
void MyDetectorConstruction::ConstructSDandField(){
  MySensitiveDetector *sensDet = new MySensitiveDetector("sensitiveDetector");
  logicDetector->SetSensitiveDetector(sensDet);
}
