#include "detector.hh"
#include "generator.hh"
#include "G4ParticleGun.hh"
#include "G4Run.hh"
#include "G4RunManager.hh"
#include "G4UImanager.hh"


MySensitiveDetector::MySensitiveDetector(G4String name) : G4VSensitiveDetector(name)
{}
//----------------------------------------------------------------------------------------------------
MySensitiveDetector::~MySensitiveDetector()
{}
//----------------------------------------------------------------------------------------------------
G4bool MySensitiveDetector::ProcessHits(G4Step *aStep, G4TouchableHistory *ROhist)
{
  // get track (any particle)
  G4Track *track = aStep->GetTrack();
  track->SetTrackStatus(fStopAndKill);

  // particle info
  G4int         trackId  = track->GetTrackID();
  G4int         parentId = track->GetParentID();
  G4int         trackPdg = track->GetParticleDefinition()->GetPDGEncoding();
  G4ThreeVector pos      = track->GetVertexPosition(); // position of the creation vertex
  G4ThreeVector pvec     = track->GetMomentum();
  G4double      energy   = track->GetTotalEnergy()/MeV;

  // run and event number
  G4int runNumber   = G4RunManager::GetRunManager()->GetCurrentRun()->GetRunID();
  G4int eventNumber = G4RunManager::GetRunManager()->GetCurrentEvent()->GetEventID();

  G4UImanager* UI = G4UImanager::GetUIpointer();
  G4UIcommand* command1 = UI->FindCommand("/gun/energy");
  G4String strEnergy = command1->GetCurrentValue();
  G4double gunEnergy;
  std::istringstream(strEnergy) >> gunEnergy;
  gunEnergy*= 1e3; // convert to MeV

  G4UIcommand* command2 = UI->FindCommand("/target/thickness");
  G4String strThickness = command2->GetCurrentValue();
  G4double targetThickness;
  std::istringstream(strThickness) >> targetThickness;

  // fill ntuple
  G4AnalysisManager *man = G4AnalysisManager::Instance();
  man->FillNtupleIColumn( 0, runNumber);
  man->FillNtupleIColumn( 1, eventNumber);
  man->FillNtupleIColumn( 2, trackId);
  man->FillNtupleIColumn( 3, parentId);
  man->FillNtupleIColumn( 4, trackPdg);
  man->FillNtupleDColumn( 5, targetThickness);
  man->FillNtupleDColumn( 6, gunEnergy);
  man->FillNtupleDColumn( 7, energy);
  man->FillNtupleDColumn( 8, pvec[0]); // px
  man->FillNtupleDColumn( 9, pvec[1]); // py
  man->FillNtupleDColumn(10, pvec[2]); // pz
  man->FillNtupleDColumn(11, pos[0]); // x
  man->FillNtupleDColumn(12, pos[1]); // y
  man->FillNtupleDColumn(13, pos[2]); // z
  man->AddNtupleRow(0);

  // print particle PDG code and momentum to the screen
  G4cout << " >>>>>>> "<< gunEnergy << " " << targetThickness << " E = " << energy << G4endl;

  return true;
}
